
# Type: interbase coordinate


TODO

URI: [biolink:interbase_coordinate](https://w3id.org/biolink/vocab/interbase_coordinate)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>OPT</sub> [String](types/String.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children

 *  [end interbase coordinate](end_interbase_coordinate.md)
 *  [start interbase coordinate](start_interbase_coordinate.md)

## Used by

 * [NamedThing](NamedThing.md)
